@@ -551,3 +551,11 @@ get_default_conf(void)
     return "config.json";
 #endif
 }
+
+uint16_t
+load16_be(const void *s)
+{
+    const uint8_t *in = (const uint8_t *)s;
+    return ((uint16_t)in[0] << 8)
+           | ((uint16_t)in[1]);
+}
